import * as KMS from '@aws-sdk/client-kms';
import { ILogger } from 'typescript-ilogger';
import { BaseClass } from 'typescript-helper-functions';
import { IKMSHelper } from './interface';
/**
 * KMS Helper
 */
export declare class KMSHelper extends BaseClass implements IKMSHelper {
    /**
     * AWS Repository for KMS
     */
    private Repository;
    /**
     * Initializes new instance of KMSHelper
     * @param logger {ILogger} Injected logger
     * @param repository {KMS.KMS} Injected Repository. A new repository will be created if not supplied
     * @param options {KMS.KMSClientConfig} Injected configuration if a Repository is supplied
     */
    constructor(logger: ILogger, repository?: KMS.KMS, options?: KMS.KMSClientConfig);
    /**
     * Decrypt KMS
     * @param encryptedValue {string} Value to decrypt
     */
    DecryptAsync(encryptedValue: string): Promise<KMS.DecryptResponse>;
    /**
     * Encrypt KMS
     * @param unencryptedValue {string} Value to encrypt
     */
    EncryptAsync(unencryptedValue: string): Promise<KMS.EncryptResponse>;
}
